spacepy.poppy.value_percentile — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- PoPPy - Point Processes in Python »

# spacepy.poppy.value_percentile

`spacepy.poppy.` `value_percentile`(sequence, target)

  Find the percentile of a particular value in a sequence

  Parameters: | sequence : sequence a sequence of values, sorted in ascending order target : same type as sequence a target value
  Returns: | out : float the percentile of target in sequence

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- PoPPy - Point Processes in Python »